package crm

import "hongze/hz_crm_eta/global"

type ChartPermissionSearchKeyWordMapping struct {
	Id                 int    `gorm:"column:id;primary_key;AUTO_INCREMENT;NOT NULL"`
	ChartPermissionId  int    `gorm:"column:chart_permission_id;default:0"`
	KeyWord            string `gorm:"column:key_word;default:"`
	From               string `gorm:"column:from;default:"`
	TacticType         string `gorm:"column:tactic_type;default:;comment:'策略表type字段值'"`
	TeleconferenceSort int    `gorm:"column:teleconference_sort;default:0;comment:'电话会类型排序'"`
}

func (c *ChartPermissionSearchKeyWordMapping) TableName() string {
	return "chart_permission_search_key_word_mapping"
}

type ClassifyPermissionReq struct {
	Keyword string
}

type ClassifyPermissionResp struct {
	List []*ChartPermissionSearchKeyWordMapping
}

func (c *ChartPermissionSearchKeyWordMapping) GetPermissionByKeyword(classifyNameSecond string) (items []*ChartPermissionSearchKeyWordMapping, err error) {
	err = global.MYSQL["hz_crm"].Where("`from`='rddp' AND key_word = ?", classifyNameSecond).Find(&items).Error
	return
}

func (c *ChartPermissionSearchKeyWordMapping) GetPermission() (items []*ChartPermissionSearchKeyWordMapping, err error) {
	err = global.MYSQL["hz_crm"].Where("`from`='rddp'").Find(&items).Error
	return
}

// ClassifyPermissionEditReq 编辑分类权限请求
type ClassifyPermissionEditReq struct {
	Keyword               string
	ChartPermissionIdList []int `description:"权限id数组"`
	NewKeyword            string
}

// EditChartPermissionSearchKeyWordMappingMulti 修改报告报告权限（先删除原有的权限，再添加新的权限）
func (c *ChartPermissionSearchKeyWordMapping) EditChartPermissionSearchKeyWordMappingMulti(keyword, newKeyword string, permissionIdList []int) (err error) {
	tx := global.MYSQL["hz_crm"].Begin()
	defer func() {
		if err != nil {
			tx.Rollback()
		} else {
			tx.Commit()
		}
	}()
	sql1 := "delete from chart_permission_search_key_word_mapping WHERE `from`='rddp' AND key_word=? "
	err = tx.Exec(sql1, keyword).Error
	if err != nil {
		return
	}
	// 删除相关联的回复
	if len(permissionIdList) > 0 {
		chartPermissionSearchKeyWordMappingList := make([]*ChartPermissionSearchKeyWordMapping, 0)
		for _, permissionId := range permissionIdList {
			tmpChartPermissionSearchKeyWordMapping := &ChartPermissionSearchKeyWordMapping{
				ChartPermissionId:  permissionId,
				KeyWord:            newKeyword,
				From:               "rddp",
				TacticType:         "",
				TeleconferenceSort: 0,
			}
			chartPermissionSearchKeyWordMappingList = append(chartPermissionSearchKeyWordMappingList, tmpChartPermissionSearchKeyWordMapping)
		}
		err = tx.CreateInBatches(chartPermissionSearchKeyWordMappingList, len(chartPermissionSearchKeyWordMappingList)).Error
	}
	return
}
