package eta

import (
	"fmt"
	"hongze/hz_crm_eta/models/eta"
	"hongze/hz_crm_eta/services/alarm_msg"
	"hongze/hz_crm_eta/utils"
)

// UpdateParentClassifyHasTel 更新父级分类是否含有电话字段
func UpdateParentClassifyHasTel(classifyId, parentId, hasTeleconference int) (err error) {
	if classifyId <= 0 || parentId <= 0 {
		return
	}
	defer func() {
		if err != nil {
			alarm_msg.SendAlarmMsg("编辑分类后-修改父级分类电话会信息失败, ErrMsg: "+err.Error(), 3)
		}
	}()
	ob := new(eta.Classify)
	parentClassify, e := ob.GetClassifyById(parentId)
	if e != nil {
		if e == utils.ErrNoRow {
			err = fmt.Errorf("父级分类不存在")
			return
		}
		err = fmt.Errorf("获取父级分类信息失败, Err: %s", e.Error())
		return
	}
	if parentClassify == nil {
		err = fmt.Errorf("父级分类不存在")
		return
	}
	updateParent := false
	updateCols := make([]string, 0)
	updateCols = append(updateCols, "HasTeleconference")
	if hasTeleconference == 1 {
		// 二级分类包含电话会，则一级分类也默认包含电话会
		if parentClassify.HasTeleconference == 0 {
			parentClassify.HasTeleconference = 1
			updateParent = true
		}
	} else {
		// 二级分类均无电话会，则一级分类也无电话会
		if parentClassify.HasTeleconference == 1 {
			child, e := eta.GetClassifyChild(parentClassify.Id, "")
			if e != nil {
				err = fmt.Errorf("获取子分类失败, Err: %s", e.Error())
				return
			}
			// 存在同一级分类下的二级分类有电话会则不变动
			hasTel := false
			for i := 0; i < len(child); i++ {
				if child[i].HasTeleconference == 1 && child[i].Id != classifyId {
					hasTel = true
					break
				}
			}
			if !hasTel {
				parentClassify.HasTeleconference = 0
				updateParent = true
			}
		}
	}
	if updateParent {
		if e = parentClassify.UpdateClassify(updateCols); e != nil {
			err = fmt.Errorf("更新父级分类失败, Err: %s", e.Error())
			return
		}
	}
	return
}
